% La fonction "rugby_simcom" évalue les /différences/ entre les
% probabilités de victoire de l'équipe B pour différentes valeurs du
% paramètre de stratégie q, en utilisant un couplage entre les simulations
% pour les différentes valeurs de q. La fonction prend en entrée la liste
% "qs" de paramètres q pour lesquels on souhaite évaluer cette différence.
% On ne commente que les parties qui diffèreent de "rugby_spl".
function rugby_simcom(qs)
% "k" est le nombre de valeurs de q qu'on souhaite comparer entre elles.
k = length(qs);
N = 15000;
% Ss sera le tableau des sommes des quantités simulées, et S2s le tableau
% des carrés de ces sommes.
Ss = zeros(k);
S2s = zeros(k);
% On lance la boucle de simulation. Comme on couple les différentes valeurs
% de q, il n'y a qu'une seule boucle pour toutes les simulations.
for i = 1:N
    % Cette fois-ci, il va falloir calculer les k scores qu'obtiendrait B
    % en suivant les k stratégies possibles. Le couplage consiste à prendre
    % des valeurs communes pour les 12-vecteurs "Balavantage" et
    % "Binscritlessai" (qui deviennent ainsi des k×12-matrices
    % "Balavatages" et "Binscritlessais"), et à coupler les valeurs des
    % 12-vecteurs "Bcherchelessai" (qui devient ainsi une k×12-matrice
    % "Bcherchelessais") en les obtenant à partir d'un même 12-vecteur de
    % variables uniformes sur [0,1].
    Balavantages = ones(k,1) * (rand(1,12) < .4);
    % Observez bien comment est obtenu "Bcherchelessais" : à gauche du
    % signe '<', on a dupliqué k fois le même vecteur de variables
    % uniformes sur [0,1] ; et à droite, la valeur à laquelle on le compare
    % dépend de la ligne.
    Bcherchelessais = (ones(k,1) * rand(1,12) < qs' * ones(1,12)) ;
    Binscritlessais = ones(k,1) * (rand(1,12) < .35);
    % "scoreB" est devenu un k-vecteur (colonne) "scoreBs" contenant le
    % score pour chacune des valeurs de q.
    scoreBs = sum(Balavantages .* (7 * Bcherchelessais .*...
        Binscritlessais + 3 * (1 - Bcherchelessais)),2);
    % Par contre, il n'y a toujours qu'un seul score pour A.
    scoreA = 3 * sum(rand(1,12) < .6);
    % "success" est la version k-vectorielle (en colonne) de "succes".
    success = (scoreBs > scoreA);
    % Ce qui nous intéresse ici n'est pas d'estimer les probabilités de
    % succès, mais leurs /différences/. "differences" est donc la tableau
    % k×k des différences entre les différentes valeurs "succes" que
    % contient "success".
    differences = success * ones(1,k) - ones(k,1) * success';
    % On met à jour "Ss" et "S2s", parallèlement pour chaque entrée des
    % tableaux.
    Ss = Ss + differences;
    S2s = S2s + differences .* differences;
end
% On calcule les estimateurs des différences de probabilités, les
% écarts-type associés, et les marges d'erreurs à 2 sigmas, tout cela
% parallèlement pour chaque couple de valeurs de q.
ms = Ss / N;
sigmas = S2s / N - ms .* ms;
erreurs = 2 * sigmas / sqrt(N);
% On affiche le résultat.
disp('Tableau des différences de probabilités: ');
disp(ms);
disp('±');
disp(erreurs);
return
end
